@@ -1,6 +1,4 @@
 /*
- * $Id$
- *
  */
 
 #ifndef SQUID_IPC_KID_H
@@ -8,7 +6,6 @@
 
 #include "SquidString.h"
 
-
 /// Squid child, including current forked process info and
 /// info persistent across restarts
 class Kid
@@ -85,7 +82,6 @@ private:
     status_type status; ///< exit status of a stopped kid
 };
 
-
 // TODO: processes may not be kids; is there a better place to put this?
 
 /// process kinds
@@ -94,10 +90,10 @@ typedef enum {
     pkCoordinator = 1, ///< manages all other kids
     pkWorker = 2, ///< general-purpose worker bee
     pkDisker = 4, ///< cache_dir manager
+    pkHelper = 8  ///< general-purpose helper child
 } ProcessKind;
 
 /// ProcessKind for the current process
 extern int TheProcessKind;
 
-
 #endif /* SQUID_IPC_KID_H */
